summaryrefslogtreecommitdiff
path: root/src/SMAPI.Web/wwwroot
diff options
context:
space:
mode:
Diffstat (limited to 'src/SMAPI.Web/wwwroot')
-rw-r--r--src/SMAPI.Web/wwwroot/Content/js/json-validator.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/SMAPI.Web/wwwroot/Content/js/json-validator.js b/src/SMAPI.Web/wwwroot/Content/js/json-validator.js
index 401efbee..72b8192b 100644
--- a/src/SMAPI.Web/wwwroot/Content/js/json-validator.js
+++ b/src/SMAPI.Web/wwwroot/Content/js/json-validator.js
@@ -71,9 +71,9 @@ smapi.LineNumberRange = function (maxLines) {
/**
* UI logic for the JSON validator page.
* @param {string} urlFormat The URL format for a file, with $schemaName and $id placeholders.
* @param {string} pasteID The Pastebin paste ID for the content being viewed, if any.
*/
-smapi.jsonValidator = function (urlFormat, pasteID) {
+smapi.jsonValidator = function (urlFormat, fileId) {
/**
* The original content element.
*/
@@ -138,7 +138,7 @@ smapi.jsonValidator = function (urlFormat, pasteID) {
// change format
$("#output #format").on("change", function() {
var schemaName = $(this).val();
- location.href = urlFormat.replace("$schemaName", schemaName).replace("$id", pasteID);
+ location.href = urlFormat.replace("$schemaName", schemaName).replace("$id", fileId);
});
// upload form
@@ -71,9 +71,9 @@ smapi.LineNumberRange = function (maxLines) {
* UI logic for the JSON validator page.
* @param {string} urlFormat The URL format for a file, with $schemaName and $id placeholders.
- * @param {string} pasteID The Pastebin paste ID for the content being viewed, if any.
+ * @param {string} fileId The file ID for the content being viewed, if any.
*/